#  tests for repoze.lru-0.7-py36_0 (this is a generated file);
print('===== testing package: repoze.lru-0.7-py36_0 =====');
print('running run_test.py');
#  --- run_test.py (begin) ---
from repoze.lru import LRUCache
#  --- run_test.py (end) ---

print('===== repoze.lru-0.7-py36_0 OK =====');
print("import: 'repoze'")
import repoze

print("import: 'repoze.lru'")
import repoze.lru

